'\"
'\" Copyright (c) 1990-1994 The Regents of the University of California.
'\" Copyright (c) 1994-1995 Sun Microsystems, Inc.
'\" Copyright (c) 1996-1999 Christian Werner
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
.so man.macros
.TH radiobutton n 8.0 Ck "Ck Built-In Commands"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
radiobutton \- Create and manipulate radiobutton widgets
.SH SYNOPSIS
\fBradiobutton\fI \fIpathName \fR?\fIoptions\fR?
.SH "STANDARD OPTIONS"
.LP
.nf
.ta 3.8c 7.6c 11.4c
\fBactiveAttributes\fR	\fBattributes\fR	\fBdisabledForeground\fR	\fBtextVariable\fR
\fBactiveBackground\fR	\fBbackground\fR	\fBforeground\fR	\fBunderline\fR
\fBactiveForeground\fR	\fBdisabledAttributes\fR	\fBtakeFocus\fR	\fBunderlineAttributes\fR
\fBanchor\fR	\fBdisabledBackground\fR	\fBtext\fR	\fBunderlineForeground\fR
.fi
.LP
See the ``options'' manual entry for details on the standard options.
.SH "WIDGET-SPECIFIC OPTIONS"
.ta 4c
.LP
.nf
Name:	\fBcommand\fR
Class:	\fBCommand\fR
Command-Line Switch:	\fB\-command\fR
.fi
.IP
Specifies a Tcl command to associate with the button.  This command
is typically invoked when mouse button 1 is pressed in the button
window.  The button's global variable (\fB\-variable\fR option) will
be updated before the command is invoked.
.LP
.nf
Name:	\fBheight\fR
Class:	\fBHeight\fR
Command-Line Switch:	\fB\-height\fR
.fi
.IP
Specifies a desired height for the button in screen lines.
If this option isn't specified, the button's desired height is 1 line.
.LP
.nf
Name:	\fBselectColor\fR
Class:	\fBBackground\fR
Command-Line Switch:	\fB\-selectcolor\fR
.fi
.IP
Specifies a background color to use when the button is selected.
If \fBindicatorOn\fR is true, the color applicies to the indicator.
.LP
.nf
Name:	\fBstate\fR
Class:	\fBState\fR
Command-Line Switch:	\fB\-state\fR
.fi
.IP
Specifies one of three states for the radiobutton:  \fBnormal\fR, \fBactive\fR,
or \fBdisabled\fR.  In normal state the radiobutton is displayed using the
\fBattributes\fR, \fBforeground\fR, and \fBbackground\fR options.
The active state is used when the input focus is in the radiobutton.
In active state the radiobutton is displayed using the
\fBactiveAttributes\fR, \fBactiveForeground\fR, and
\fBactiveBackground\fR options.
Disabled state means that the radiobutton should be insensitive:
the default bindings will refuse to activate the widget and will ignore mouse
button presses.
In this state the \fBdisabledAttributes\fR, \fBdisabledForeground\fR and
\fBdisabledBackground\fR options determine how the radiobutton is displayed.
.LP
.nf
Name:	\fBvalue\fR
Class:	\fBValue\fR
Command-Line Switch:	\fB\-value\fR
.fi
.IP
Specifies value to store in the button's associated variable whenever
this button is selected.
.LP
.nf
Name:	\fBvariable\fR
Class:	\fBVariable\fR
Command-Line Switch:	\fB\-variable\fR
.fi
.IP
Specifies name of global variable to set whenever this button is
selected.  Changes in this variable also cause the button to select
or deselect itself. Defaults to the value \fBselectedButton\fR.
.LP
.nf
Name:	\fBwidth\fR
Class:	\fBWidth\fR
Command-Line Switch:	\fB\-width\fR
.fi
.IP
Specifies a desired width for the button in screen columns.
If this option isn't specified, the button's desired width is computed
from the size of the text being displayed in it.
.BE

.SH DESCRIPTION
.PP
The \fBradiobutton\fR command creates a new window (given by the
\fIpathName\fR argument) and makes it into a radiobutton widget.
Additional options, described above, may be specified on the command line
or in the option database to configure aspects of the radiobutton such as
its colors, attributes, and text. The \fBradiobutton\fR command returns its
\fIpathName\fR argument.  At the time this command is invoked,
there must not exist a window named \fIpathName\fR, but
\fIpathName\fR's parent must exist.
.PP
A radiobutton is a widget that displays a textual string
and a circle called an \fIindicator\fR.
One of the characters of the string may optionally be underlined
using the \fBunderline\fR, \fBunderlineAttributes\fR, and
\fBunderlineForeground\fR options.
A radiobutton has all of the behavior of a simple button:
it can display itself in either of three different ways,
according to the \fBstate\fR option, and it invokes
a Tcl command whenever mouse button 1 is clicked over the
check button.
.PP
In addition, radiobuttons can be \fIselected\fR.
If a radiobutton is selected, the indicator is normally
drawn with a special color, and a Tcl variable associated with the
radiobutton is set to a particular value.
If the radiobutton is not selected, the indicator is drawn with no
special color. Typically, several radiobuttons share a single variable
and the value of the variable indicates which radiobutton is to be selected.
When a radiobutton is selected it sets the value of the variable to
indicate that fact;  each radiobutton also monitors the value of
the variable and automatically selects and deselects itself when the
variable's value changes.
By default the variable \fBselectedButton\fR
is used;  its contents give the name of the button that is
selected, or the empty string if no button associated with that
variable is selected.
The name of the variable for a radiobutton,
plus the variable to be stored into it, may be modified with options
on the command line or in the option database.
Configuration options may also be used to modify the way the
indicator is displayed.
By default a radio button is configured to select itself on button clicks.

.SH "WIDGET COMMAND"
.PP
The \fBradiobutton\fR command creates a new Tcl command whose
name is \fIpathName\fR.  This
command may be used to invoke various
operations on the widget.  It has the following general form:
.DS C
\fIpathName option \fR?\fIarg arg ...\fR?
.DE
\fIOption\fR and the \fIarg\fRs
determine the exact behavior of the command.  The following
commands are possible for radiobutton widgets:
.TP
\fIpathName \fBcget\fR \fIoption\fR
Returns the current value of the configuration option given
by \fIoption\fR.
\fIOption\fR may have any of the values accepted by the \fBradiobutton\fR
command.
.TP
\fIpathName \fBconfigure\fR ?\fIoption\fR? ?\fIvalue option value ...\fR?
Query or modify the configuration options of the widget.
If no \fIoption\fR is specified, returns a list describing all of
the available options for \fIpathName\fR. If \fIoption\fR is specified
with no \fIvalue\fR, the command returns a list describing the
one named option (this list will be identical to the corresponding
sublist of the value returned if no \fIoption\fR is specified).  If
one or more \fIoption\-value\fR pairs are specified, the command
modifies the given widget option(s) to have the given value(s);  in
this case the command returns an empty string.
\fIOption\fR may have any of the values accepted by the \fBradiobutton\fR
command.
.TP
\fIpathName \fBdeselect\fR
Deselects the radiobutton and sets the associated variable to an
empty string.
If this radiobutton was not currently selected, the command has
no effect.
.TP
\fIpathName \fBinvoke\fR
Does just what would have happened if the user invoked the radiobutton
with the mouse: selects the button and invokes
its associated Tcl command, if there is one.
The return value is the return value from the Tcl command, or an
empty string if there is no command associated with the radiobutton.
This command is ignored if the radiobutton's state is \fBdisabled\fR.
.TP
\fIpathName \fBselect\fR
Selects the radiobutton and sets the associated variable to the
value corresponding to this widget.

.SH BINDINGS
.PP
Ck automatically creates class bindings for radiobuttons that give them
the following default behavior:
.IP [1]
The radiobutton activates whenever it gets the input focus and deactivates
whenever it loses the input focus.
.IP [2]
When mouse button 1 is pressed over a radiobutton it is invoked (it
becomes selected and the command associated with the button is
invoked, if there is one).
.IP [3]
When a radiobutton has the input focus, the space or return keys cause
the radiobutton to be invoked.
.PP
If the radiobutton's state is \fBdisabled\fR then none of the above
actions occur:  the radiobutton is completely non-responsive.
.PP
The behavior of radiobuttons can be changed by defining new bindings for
individual widgets or by redefining the class bindings.

.SH KEYWORDS
radiobutton, widget
